@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR::Avoided;
 
-our $DATE = '2016-02-25'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2016-03-09'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 our @Module_Lists = (
     {
@@ -67,6 +67,30 @@ you can also use it like this:
 _
                 alternate_modules => ['Exporter'],
             },
+            {
+                module => 'JSON',
+                summary => 'Somewhat broken',
+                description => <<'_',
+
+JSON.pm is a discouraged module now, due to its somewhat broken backend handling
+and lack of support for `Cpanel::JSON::XS`. consider switching to JSON::MaybeXS
+or perhaps just JSON::PP.
+
+_
+                alternate_modules => ['JSON::MaybeXS', 'JSON::PP', 'Cpanel::JSON::XS'],
+            },
+            {
+                module => 'JSON::XS',
+                summary => '',
+                description => <<'_',
+
+`Cpanel::JSON::XS` is the fork of `JSON::XS` that fixes some bugs and adds some
+features, mainly so it's more compatible with `JSON::PP`. See the documentation
+of `Cpanel::JSON::XS` for more details on those.
+
+_
+                alternate_modules => ['Cpanel::JSON::XS'],
+            },
         ],
     },
 );
@@ -86,7 +110,7 @@ Acme::CPANLists::PERLANCAR::Avoided - Modules I'm currently avoiding
 
 =head1 VERSION
 
-This document describes version 0.11 of Acme::CPANLists::PERLANCAR::Avoided (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-02-25.
+This document describes version 0.12 of Acme::CPANLists::PERLANCAR::Avoided (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-03-09.
 
 =head1 MODULE LISTS
 
@@ -141,6 +165,24 @@ you can also use it like this:
 
 Alternate modules: L<Exporter>
 
+=item * L<JSON> - Somewhat broken
+
+JSON.pm is a discouraged module now, due to its somewhat broken backend handling
+and lack of support for C<Cpanel::JSON::XS>. consider switching to JSON::MaybeXS
+or perhaps just JSON::PP.
+
+
+Alternate modules: L<JSON::MaybeXS>, L<JSON::PP>, L<Cpanel::JSON::XS>
+
+=item * L<JSON::XS>
+
+C<Cpanel::JSON::XS> is the fork of C<JSON::XS> that fixes some bugs and adds some
+features, mainly so it's more compatible with C<JSON::PP>. See the documentation
+of C<Cpanel::JSON::XS> for more details on those.
+
+
+Alternate modules: L<Cpanel::JSON::XS>
+
 =back
 
 =head1 HOMEPAGE
